qstock由“Python金融量化”公众号开发，试图打造成个人量化投研分析包，目前包括数据获取（data）、可视化(plot)、选股(stock)和量化回测（策略backtest）模块。

其中数据模块（data）数据来源：东方财富网、同花顺、新浪财经等网上公开数据，数据爬虫部分参考了金融数据包tushare、akshare和efinance，qstock将为用户提供更加简洁的数据接口和规整化后的金融市场数据。

可视化模块整合了plotly.express和pyecharts包的功能，为用户提供基本图形的简单操作接口；

选股模块提供了同花顺的选股数据和自定义选股，包括RPS、MM趋势、财务指标、资金流模型等；

回测模块为大家提供向量化（基于pandas）和基于事件驱动的基本框架和模型。

选股和回测模块某些功能完整版提供给Python金融量化知识星球会员使用。

关注“Python金融量化“微信公众号，获取更多应用信息。

交流可添加个人微信“sky2blue2”

代码仅供用户学习交流用，切勿用做商用！